# RuntimeManagement

RuntimeManagement defines suggestions for runtime controllers to manage the runtime
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**clean_cache_policy** | [**CleanCachePolicy**](CleanCachePolicy.md) |  | [optional] 
**metadata_sync_policy** | [**MetadataSyncPolicy**](MetadataSyncPolicy.md) |  | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


